@@ -335,8 +335,13 @@ arma::field<arma::field<arma::mat> > model_select(arma::vec& data,
                                                   bool bs_optimism,
                                                   double alpha,
                                                   std::string compute_v, 
-                                                  unsigned int K, unsigned int H, unsigned int G, 
-                                                  bool robust, double eff, unsigned int seed){
+                                                  unsigned int K, 
+                                                  unsigned int H, 
+                                                  unsigned int G, 
+                                                  bool robust, 
+                                                  double eff, 
+                                                  unsigned int seed
+                                                  ){
   
   // Number of data points
   unsigned int N = data.n_rows;
@@ -379,7 +384,8 @@ arma::field<arma::field<arma::mat> > model_select(arma::vec& data,
                                                   "fast", // compute V
                                                   K, H,
                                                   G, 
-                                                  robust, eff);
+                                                  robust, 
+                                                  eff);
   
   // Theta update
   theta = master(0);
@@ -640,9 +646,16 @@ arma::field< arma::field<arma::field<arma::mat> > >  rank_models_cpp(arma::vec&
                                                                      const std::vector<std::vector < std::string > >& model_str, 
                                                                      const std::vector< std::string >&  full_model,
                                                                      double alpha, 
-                                                                     std::string compute_v, std::string model_type, 
-                                                                     unsigned int K, unsigned int H, unsigned int G, 
-                                                                     bool robust, double eff, bool bs_optimism, unsigned int seed){
+                                                                     std::string compute_v, 
+                                                                     std::string model_type, 
+                                                                     unsigned int K, 
+                                                                     unsigned int H,
+                                                                     unsigned int G, 
+                                                                     bool robust,
+                                                                     double eff,
+                                                                     bool bs_optimism,
+                                                                     unsigned int seed
+                                                                     ){
   
   
   std::set<std::vector < std::string > > models = vector_to_set(model_str);
